__version__="2025.0514.1748"
__author__ ="Ludwig Corales M. dexsys@gmail.com"
__all__=['ClearCrt','CleanText','Color','logs','ProgressBar','Table',
         '_PRUEBA','_TIPOEJECUCION','PrintError','Cronometro','ImportarHojasXLSX',
         'EnviarCorreoAdjunto','emailSender','Box','toVars','GenerateQuery']

#,'','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','']from .Funciones import leer_pdf

from .libPy2023 import ClearCrt,CleanText,Color,logs,ProgressBar,Table,\
         _PRUEBA,_TIPOEJECUCION,PrintError,Cronometro,ImportarHojasXLSX,\
         EnviarCorreoAdjunto,emailSender,Box,toVars,GenerateQuery